Contrast class

Constructors

Contrast()

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Methods

contrastRatio(dynamic lighterL, dynamic darkerL) → double
darkerMaxL(double r, double lighterL) → double
lighterMinL(double r) → double

Constants

W3C_CONTRAST_LARGE_TEXT → const double
W3C_CONTRAST_TEXT → const double